balafon
===============================================
* `Overview`_
* `Quick start`_

.. _Overview: #overviex
.. _Quick start: #quick-start


.. _overview:

Overview
------------------------------------

balafon moto is Organize > Target > Communicate. It helps you to work with your contacts in your day-to-day work

.. _quick-start:

Quick start
-----------

Python 2.6+, Django 1.6+ required


License
=======

CeCCIL 2.1. see license.txt
